@@ -5,7 +5,9 @@ struct SlotMeta {
   SV *name;
   ClassMeta *class;
   SV *defaultsv;
+  OP *defaultexpr; /* at most one of defaultsv or defaultexpr should be set */
   SLOTOFFSET slotix;
+  SV *paramname;
   AV *hooks; /* NULL, or AV of raw pointers directly to SlotHook structs */
 };
 
@@ -15,7 +17,7 @@ struct SlotMeta {
     for(hooki = 0; slotmeta->hooks && hooki < av_count(slotmeta->hooks); hooki++) {       \
       struct SlotHook *h = (struct SlotHook *)AvARRAY(slotmeta->hooks)[hooki];            \
       if(*h->funcs->func)                                                                 \
-        (*h->funcs->func)(aTHX_ slotmeta, h->hookdata);                                   \
+        (*h->funcs->func)(aTHX_ slotmeta, h->hookdata, h->funcdata);                      \
     }                                                                                     \
   }
 
@@ -25,7 +27,7 @@ struct SlotMeta {
     for(hooki = 0; slotmeta->hooks && hooki < av_count(slotmeta->hooks); hooki++) {       \
       struct SlotHook *h = (struct SlotHook *)AvARRAY(slotmeta->hooks)[hooki];            \
       if(*h->funcs->func)                                                                 \
-        (*h->funcs->func)(aTHX_ slotmeta, h->hookdata, __VA_ARGS__);                      \
+        (*h->funcs->func)(aTHX_ slotmeta, h->hookdata, h->funcdata, __VA_ARGS__);         \
     }                                                                                     \
   }
 
